@@ -13,9 +13,9 @@ pub enum GraphicsStyle {
     /// Set the missing style of PointSize
     PointSize(PointSize),
     /// Set the missing style of PointColor
-    PointColor(PointColor),
+    PointColor(RGBA),
     /// Set the missing style of LineColor
-    LineColor(LineColor),
+    LineColor(RGBA),
     /// Set the missing style of LineWidth
     LineWidth(LineWidth),
 }
@@ -23,8 +23,8 @@ pub enum GraphicsStyle {
 #[derive(Debug, Clone)]
 pub(crate) struct StyleContext {
     pub point_size: Option<PointSize>,
-    pub point_color: Option<PointColor>,
-    pub line_color: Option<LineColor>,
+    pub point_color: Option<RGBA>,
+    pub line_color: Option<RGBA>,
     pub line_width: Option<LineWidth>,
 }
 
@@ -33,13 +33,13 @@ impl StyleResolver {
     pub fn point_size(&self) -> PointSize {
         self.local.point_size.unwrap_or(self.theme.point_size.unwrap_or(PointSize::default()))
     }
-    /// Set the value of [`PointColor`]
-    pub fn point_color(&self) -> PointColor {
-        self.local.point_color.unwrap_or(self.theme.point_color.unwrap_or(PointColor::default()))
+    /// Set the value of [`RGBA`]
+    pub fn point_color(&self) -> RGBA {
+        self.local.point_color.unwrap_or(self.theme.point_color.unwrap_or(RGBA::default()))
     }
-    /// Set the value of [`LineColor`]
-    pub fn line_color(&self) -> LineColor {
-        self.local.line_color.unwrap_or(self.theme.line_color.unwrap_or(LineColor::default()))
+    /// Set the value of [`RGBA`]
+    pub fn line_color(&self) -> RGBA {
+        self.local.line_color.unwrap_or(self.theme.line_color.unwrap_or(RGBA::default()))
     }
     /// Set the value of [`LineWidth`]
     pub fn line_width(&self) -> LineWidth {
@@ -67,16 +67,7 @@ impl From<PointSize> for GraphicsStyle {
         Self::PointSize(s)
     }
 }
-impl From<PointColor> for GraphicsStyle {
-    fn from(s: PointColor) -> Self {
-        Self::PointColor(s)
-    }
-}
-impl From<LineColor> for GraphicsStyle {
-    fn from(s: LineColor) -> Self {
-        Self::LineColor(s)
-    }
-}
+
 impl From<LineWidth> for GraphicsStyle {
     fn from(s: LineWidth) -> Self {
         Self::LineWidth(s)
